@@ -42,8 +42,7 @@ class CNV(object):
         profile['timeS'] # Return the time in Seconds
         profile.attributes # Return a dictionary with the file header
     """
-    def __init__(self, raw_text, defaults=None, verbose=False):
-        self.verbose = verbose
+    def __init__(self, raw_text, defaults=None):
         self.raw_text = raw_text
         self.defaults = defaults
         self.attributes = {}
@@ -104,8 +103,7 @@ class CNV(object):
             r = rule['header'] + rule['sep'] + rule['data']
             content_re = re.compile(r, re.VERBOSE)
             if re.search(r, self.raw_text, re.VERBOSE):
-                if self.verbose is True:
-                    print "Using rules from: ", rule_file
+                print "Using rules from: ", rule_file
                 self.rule = rule
                 self.parsed = content_re.search(self.raw_text).groupdict()
                 return
@@ -187,14 +185,18 @@ class CNV(object):
               number of rows? Maybe do it free, and on checks, validate it.
               In the case of an incomplete file, I think I should load it
               anyways, and the check alerts me that it is missing data.
+
+            There is a problem here. This atol is just a temporary solution,
+              but it's not the proper way to handle it.
         """
         #data = ma.masked_values([d.split() for d in self.raw_data()['data'].split('\r\n')[:-1]],  float(self.attributes['bad_flag']))
+        data_rows = re.sub('(\r\n\s*)+\r\n', '\r\n',
+                self.raw_data()['data']).split('\r\n')[:-1]
         data = ma.masked_values(
                 np.array(
-                    [d.split() for d in
-                    self.raw_data()['data'].split('\r\n')[:-1]],
-                    dtype=np.float),
-                float(self.attributes['bad_flag']))
+                    [d.split() for d in data_rows], dtype=np.float),
+                float(self.attributes['bad_flag']),
+                atol = 1e-30)
         # Talvez usar o np.fromstring(data, sep=" ")
         for i in self.ids:
             attributes = self.data[i].attributes
@@ -290,46 +292,43 @@ class CNV(object):
             !! ATENTION!!! Might be a good idea to store lat,lon as floats
               with min. and sec. as fractions.
         """
+        if 'latitude' in self.attributes:
+                lat = re.search(self.rule['latitude'],
+                        self.attributes['latitude'],
+                        re.VERBOSE).groupdict()
+        elif 'notes' in self.raw_header().keys():
+                lat = re.search(self.rule['latitude'],
+                        self.raw_header()['notes'],
+                        re.VERBOSE).groupdict()
         try:
-            if 'latitude' in self.attributes:
-                    lat = re.search(self.rule['latitude'],
-                            self.attributes['latitude'],
-                            re.VERBOSE).groupdict()
-            elif 'notes' in self.raw_header().keys():
-                    lat = re.search(self.rule['latitude'],
-                            self.raw_header()['notes'],
-                            re.VERBOSE).groupdict()
-
-            lat_deg = int(lat['degree'])
-            lat_min = float(lat['minute'])
-            #self.attributes['lat_deg'] = lat_deg
-            #self.attributes['lat_min'] = lat_min
-            self.attributes['latitude'] = lat_deg + lat_min/60.
-            if lat['hemisphere'] in ['S', 's']:
-                self.attributes['latitude'] = -1*self.attributes['latitude']
+                lat_deg = int(lat['degree'])
+                lat_min = float(lat['minute'])
+                #self.attributes['lat_deg'] = lat_deg
+                #self.attributes['lat_min'] = lat_min
+                self.attributes['latitude'] = lat_deg + lat_min/60.
+                if lat['hemisphere'] in ['S', 's']:
+                    self.attributes['latitude'] = -1*self.attributes['latitude']
         except:
-                #self.attributes['latitude'] = None
                 pass
 
-        try:
-            if 'longitude' in self.attributes:
-                    lon = re.search(self.rule['longitude'],
-                            self.attributes['longitude'],
-                            re.VERBOSE).groupdict()
-            elif 'notes' in self.raw_header().keys():
-                    lon = re.search(self.rule['longitude'],
-                            self.raw_header()['notes'],
-                            re.VERBOSE).groupdict()
+        if 'longitude' in self.attributes:
+                lon = re.search(self.rule['longitude'],
+                        self.attributes['longitude'],
+                        re.VERBOSE).groupdict()
+        elif 'notes' in self.raw_header().keys():
+                lon = re.search(self.rule['longitude'],
+                        self.raw_header()['notes'],
+                        re.VERBOSE).groupdict()
 
-            lon_deg = int(lon['degree'])
-            lon_min = float(lon['minute'])
-            #self.attributes['lon_deg'] = lon_deg
-            #self.attributes['lon_min'] = lon_min
-            self.attributes['longitude'] = lon_deg + lon_min/60.
-            if lon['hemisphere'] in ['W', 'w']:
-                self.attributes['longitude'] = -1*self.attributes['longitude']
+        try:
+                lon_deg = int(lon['degree'])
+                lon_min = float(lon['minute'])
+                #self.attributes['lon_deg'] = lon_deg
+                #self.attributes['lon_min'] = lon_min
+                self.attributes['longitude'] = lon_deg + lon_min/60.
+                if lon['hemisphere'] in ['W', 'w']:
+                    self.attributes['longitude'] = -1*self.attributes['longitude']
         except:
-                #self.attributes['longitude'] = None
                 pass
 
     def as_DataFrame(self):
@@ -349,10 +348,8 @@ class CNV(object):
             tmp[self[k].mask] = np.nan
             output[k] = tmp
         output = pd.DataFrame(output)
-        toload = ['latitude', 'longitude', 'datetime']
-        for a in toload:
-            if a in self.attributes:
-                output[a] = self.attributes[a]
+        output['latitude'] = self.attributes['latitude']
+        output['longitude'] = self.attributes['longitude']
 
         return output
 
